CREATE OR REPLACE VIEW V_FOREIGN_RATE AS (
  SELECT P.TUJAVALUTA AS FOREIGN_CURRENCY, (SELECT T.TECAJ FROM TECAJ T WHERE T.NVALUTA = P.TUJAVALUTA AND T.NTECAJ = 'S' 
  AND T.DATUM = (SELECT MAX(T2.DATUM) FROM TECAJ T2 WHERE T2.NVALUTA = P.TUJAVALUTA AND T2.NTECAJ = 'S')) AS LAST_MIDDLE_RATE
  FROM PARAM P
);

CREATE OR REPLACE VIEW V_KUPCI AS (
	SELECT K.ID, K.ID_MEMBER, K.IME, K.PRIIMEK, K.MESTO, K.NASLOV, K.POSTA, K.TELEFON_1, K.EMAIL, K.YACHT_CLUB_ID, K.TELEX, K.VRSTA, K.NDRZAVA, K.SALDAKONTI_SIT, K.SALDAKONTI_DEM, K.SALDAKONTI_KOM,
	NNTIT.INTERNI_OPIS AS NNTITLE_DESC, NNDRZ.INTERNI_OPIS AS NNDRZAVA_DESC, NNDOK.INTERNI_OPIS AS VRSTA_DOKUMENTA_DESC, NNVRS.INTERNI_OPIS AS VRSTA_DESC,
	NNDRZDR.INTERNI_OPIS AS DRZAVA_ROJSTVA_DESC, NNDRZCI.INTERNI_OPIS AS CITIZENSHIP_DESC, NNMAR.INTERNI_OPIS AS MARITAL_STATUS_DESC,
  
    -- Owner balance data
    K.SALDAKONTI_SIT + NVL(K.SALDAKONTI_DEM, 0) * (SELECT NVL(LAST_MIDDLE_RATE, 1) FROM V_FOREIGN_RATE) AS BALANCE, 
    CASE WHEN K.VALUTA_PLACILA = (SELECT TUJAVALUTA FROM PARAM) THEN NVL(K.SALDAKONTI_KOM, 0)*(-1)*(SELECT NVL(LAST_MIDDLE_RATE, 1) FROM V_FOREIGN_RATE) ELSE NVL(K.SALDAKONTI_KOM, 0)*(-1) END AS COMMERCIAL_BALANCE,
    
    (K.SALDAKONTI_SIT + NVL(K.SALDAKONTI_DEM, 0) * (SELECT NVL(LAST_MIDDLE_RATE, 1) FROM V_FOREIGN_RATE)) + 
    (CASE WHEN K.VALUTA_PLACILA = (SELECT TUJAVALUTA FROM PARAM) THEN NVL(K.SALDAKONTI_KOM, 0)*(-1)*(SELECT NVL(LAST_MIDDLE_RATE, 1) FROM V_FOREIGN_RATE) ELSE NVL(K.SALDAKONTI_KOM, 0)*(-1) END) AS TOTAL_BALANCE,
    
    ((SELECT NVL(SUM(S.ZA_PLACILO - S.PORABLJENO), 0) FROM SALDKONT S WHERE S.ID_KUPCA = K.ID AND UPPER(S.VALUTA_RN) = K.VALUTA_PLACILA AND UPPER(S.SDK_RN_PL) = 'P' AND UPPER(S.SDK_RN_TIP) = 'I' AND S.ZAPRTO = '0' AND S.DATUM_VALUTACIJE < SYSDATE) -
    (SELECT NVL(SUM(S.ZA_PLACILO - S.PORABLJENO), 0) FROM SALDKONT S WHERE S.ID_KUPCA = K.ID AND UPPER(S.VALUTA_RN) = K.VALUTA_PLACILA AND UPPER(S.SDK_RN_PL) = 'R' AND UPPER(S.SDK_RN_TIP) = 'I' AND S.ZAPRTO = '0' AND S.DATUM_VALUTACIJE < SYSDATE)) AS OUTSTANDING_BALANCE,
  
    -- Owner contract data
   (SELECT OBJEKT FROM M_POGODBE M WHERE M.ID_LASTNIKA = K.ID AND M.ID_PLOVILA IS NULL AND ROWNUM = 1 AND M.DATUM_ZACETKA = (SELECT MAX(M2.DATUM_ZACETKA) FROM M_POGODBE M2 WHERE M2.ID_LASTNIKA = K.ID AND M2.ID_PLOVILA IS NULL) ) AS POGODBA_OBJEKT,
   (SELECT N_PRIVEZA FROM M_POGODBE M WHERE M.ID_LASTNIKA = K.ID AND M.ID_PLOVILA IS NULL AND ROWNUM = 1 AND M.DATUM_ZACETKA = (SELECT MAX(M2.DATUM_ZACETKA) FROM M_POGODBE M2 WHERE M2.ID_LASTNIKA = K.ID AND M2.ID_PLOVILA IS NULL) ) AS POGODBA_PRIVEZ
   
	FROM KUPCI K
	LEFT OUTER JOIN NNTITLE NNTIT ON K.NTITLE = NNTIT.SIFRA
	LEFT OUTER JOIN NNDRZAVE NNDRZ ON K.NDRZAVA = NNDRZ.SIFRA
	LEFT OUTER JOIN NNDOKUME NNDOK ON K.VRSTA_DOKUMENTA = NNDOK.SIFRA
	LEFT OUTER JOIN NNVRSKUP NNVRS ON K.VRSTA = NNVRS.SIFRA
	LEFT OUTER JOIN NNDRZAVE NNDRZDR ON K.DRZAVA_ROJSTVA = NNDRZDR.SIFRA
	LEFT OUTER JOIN NNDRZAVE NNDRZCI ON K.CITIZENSHIP = NNDRZCI.SIFRA
	LEFT OUTER JOIN NNMARSTAT NNMAR ON K.MARITAL_STATUS = NNMAR.SIFRA
);

CREATE OR REPLACE VIEW V_KUPCI_PLOVILA AS (
  SELECT CONCAT(CONCAT(K.ID, '-'), P.ID) AS KUPCI_PLOVILA_ID, K.ID AS ID_LASTNIKA, K.IME AS KUPCI_IME, K.PRIIMEK AS KUPCI_PRIIMEK, K.NASLOV AS KUPCI_NASLOV, K.MESTO AS KUPCI_MESTO, K.POSTA AS KUPCI_POSTA, K.VRSTA AS KUPCI_VRSTA,
  K.NDRZAVA AS KUPCI_NDRZAVA, K.EMAIL AS KUPCI_EMAIL, K.TELEFON_1 AS KUPCI_TELEFON_1, K.YACHT_CLUB_ID, K.ID_MEMBER AS KUPCI_ID_MEMBER, K.ACT AS KUPCI_ACT, K.TELEX AS KUPCI_TELEX, K.GSM AS KUPCI_GSM, K.TELEFON_2 AS KUPCI_TELEFON_2, 
  K.DAVCNA_STEVILKA AS KUPCI_DAVCNA_STEVILKA, K.VALUTA_PLACILA AS KUPCI_VALUTA_PLACILA, K.SALDAKONTI_SIT AS KUPCI_SALDAKONTI_SIT, K.SALDAKONTI_DEM AS KUPCI_SALDAKONTI_DEM, K.SALDAKONTI_KOM AS KUPCI_SALDAKONTI_KOM,
  VK.BALANCE AS OWNER_BALANCE, VK.COMMERCIAL_BALANCE AS OWNER_COMMERCIAL_BALANCE, VK.TOTAL_BALANCE AS OWNER_TOTAL_BALANCE, VK.OUTSTANDING_BALANCE AS OWNER_OUTSTANDING_BALANCE,
  P.ID AS PLOVILA_ID, P.IME AS PLOVILA_IME, P.REGISTRSKA_N AS PLOVILA_REGISTRSKA_N, P.MODEL AS PLOVILA_MODEL, P.NTIP AS PLOVILA_NTIP, P.NZASTAVA AS PLOVILA_NZASTAVA, P.TRENUTNI_OBJEKT_PRIVEZA, P.TRENUTNA_N_PRIVEZA, P.TRENUTNO_DO, 
  P.POGODBENI_OBJEKT_PRIVEZA, P.POGODBENA_N_PRIVEZA, P.POGODBA_DO, P.DOLZINA AS PLOVILA_DOLZINA, P.SIRINA AS PLOVILA_SIRINA, P.GREZ AS PLOVILA_GREZ, P.BOOKING AS PLOVILA_BOOKING, P.ACT AS PLOVILA_ACT, VPT.ID_PRIVEZ AS ID_PRIVEZ_TEMP, 
  VPT.NNLOCATION_ID AS ID_LOCATION_TEMP, VPC.ID_PRIVEZ AS ID_PRIVEZ_CONTRACT, VPC.NNLOCATION_ID AS ID_LOCATION_CONTRACT, VK.POGODBA_OBJEKT AS KUPCI_POGODBA_OBJEKT, VK.POGODBA_PRIVEZ AS KUPCI_POGODBA_PRIVEZ
  FROM KUPCI K
  LEFT OUTER JOIN PLOVILA P ON P.ID_LASTNIKA = K.ID
  LEFT OUTER JOIN V_KUPCI VK ON VK.ID = K.ID
  LEFT OUTER JOIN V_PRIVEZ_LOCATION VPT ON VPT.OBJEKT = P.TRENUTNI_OBJEKT_PRIVEZA AND VPT.N_PRIVEZA = P.TRENUTNA_N_PRIVEZA
  LEFT OUTER JOIN V_PRIVEZ_LOCATION VPC ON VPC.OBJEKT = P.POGODBENI_OBJEKT_PRIVEZA AND VPC.N_PRIVEZA = P.POGODBENA_N_PRIVEZA
);

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (977, SYSDATE, '5.5', 897, 'VKupci saldo tecaj');